==> 12.8.2.tar.gz: lib/src/models/single_component_response_of_destiny_item_instance_component.dart <==
import 'package:json_annotation/json_annotation.dart';

import 'destiny_item_instance_component.dart';
import '../enums/component_privacy_setting.dart';

part 'single_component_response_of_destiny_item_instance_component.g.dart';

@JsonSerializable()
class SingleComponentResponseOfDestinyItemInstanceComponent{
	
	SingleComponentResponseOfDestinyItemInstanceComponent();

	factory SingleComponentResponseOfDestinyItemInstanceComponent.fromJson(Map<String, dynamic> json) {
		try{
			return _$SingleComponentResponseOfDestinyItemInstanceComponentFromJson(json);
		}catch(e){
			print(e);
		}
		return null;
	}

	/// If an item is "instanced", this will contain information about the item's instance that doesn't fit easily into other components. One might say this is the "essential" instance data for the item.
	/// Items are instanced if they require information or state that can vary. For instance, weapons are Instanced: they are given a unique identifier, uniquely generated stats, and can have their properties altered. Non-instanced items have none of these things: for instance, Glimmer has no unique properties aside from how much of it you own.
	/// You can tell from an item's definition whether it will be instanced or not by looking at the DestinyInventoryItemDefinition's definition.inventory.isInstanceItem property.
	@JsonKey(name:'data')
	DestinyItemInstanceComponent data;
	@JsonKey(name:'privacy',unknownEnumValue:ComponentPrivacySetting.ProtectedInvalidEnumValue)
	ComponentPrivacySetting privacy;
	/// If true, this component is disabled.
	@JsonKey(name:'disabled')
	bool disabled;

	
	
	Map<String, dynamic> toJson() => _$SingleComponentResponseOfDestinyItemInstanceComponentToJson(this);
}

==> 13.12.1.tar.gz: lib/src/models/single_component_response_of_destiny_item_instance_component.dart <==
import 'package:json_annotation/json_annotation.dart';

import 'destiny_item_instance_component.dart';
import '../enums/component_privacy_setting.dart';

part 'single_component_response_of_destiny_item_instance_component.g.dart';

@JsonSerializable()
class SingleComponentResponseOfDestinyItemInstanceComponent{
	
	SingleComponentResponseOfDestinyItemInstanceComponent();

	factory SingleComponentResponseOfDestinyItemInstanceComponent.fromJson(Map<String, dynamic> json) {
		return _$SingleComponentResponseOfDestinyItemInstanceComponentFromJson(json);
	}

	/// If an item is "instanced", this will contain information about the item's instance that doesn't fit easily into other components. One might say this is the "essential" instance data for the item.
	/// Items are instanced if they require information or state that can vary. For instance, weapons are Instanced: they are given a unique identifier, uniquely generated stats, and can have their properties altered. Non-instanced items have none of these things: for instance, Glimmer has no unique properties aside from how much of it you own.
	/// You can tell from an item's definition whether it will be instanced or not by looking at the DestinyInventoryItemDefinition's definition.inventory.isInstanceItem property.
	@JsonKey(name:'data')
	DestinyItemInstanceComponent? data;
	@JsonKey(name:'privacy',unknownEnumValue:ComponentPrivacySetting.ProtectedInvalidEnumValue)
	ComponentPrivacySetting? privacy;
	/// If true, this component is disabled.
	@JsonKey(name:'disabled')
	bool? disabled;

	
	
	Map<String, dynamic> toJson() => _$SingleComponentResponseOfDestinyItemInstanceComponentToJson(this);
}
